@@ -2,10 +2,9 @@
 #'
 #' @description \code{lsa.crosstabs} computes two-way tables and estimates the Rao-Scott first- and second-order adjusted chi-square.
 #'
-#' @param data.file       The file containing \code{lsa.data} object. Either this or
-#'                        \code{data.object}
-#'                        shall be specified, but not both. See details.
-#' @param data.object     The object in the memory containing \code{lsa.data} object. Either this
+#' @param data.file       A file containing \code{lsa.data} object. Either this or
+#'                        \code{data.object} shall be specified, but not both. See details.
+#' @param data.object     An object in the memory containing \code{lsa.data}. Either this
 #'                        or \code{data.file} shall be specified, but not both. See details.
 #' @param split.vars      Categorical variable(s) to split the results by. If no split variables
 #'                        are provided, the results will be for the overall countries'
@@ -37,12 +36,15 @@
 #'                        applied? The default (\code{FALSE}) applies the "full" design when
 #'                        computing the variance components and the standard errors of the
 #'                        estimates.
-#' @param output.file     Full path to the output file including the file name. If omitted, a file
-#'                        with a default file name "Analysis.xlsx" will be written to the working
-#'                        directory (\code{getwd()}).
+#' @param save.output     Logical, shall the output be saved in MS Excel file (default) or not
+#'                        (printed to the console or assigned to an object).
+#' @param output.file     If \code{save.output = TRUE} (default), full path to the output file
+#'                        including the file name. If omitted, a file with a default file name
+#'                        "Analysis.xlsx" will be written to the working directory
+#'                        (\code{getwd()}). Ignored if \code{save.output = FALSE}.
 #' @param open.output     Logical, shall the output be open after it has been written? The default
 #'                        (\code{TRUE}) opens the output in the default spreadsheet program
-#'                        installed on the computer.
+#'                        installed on the computer. Ignored if \code{save.output = FALSE}.
 #'
 #' @details
 #' The function computes two-way tables between two categorical variables and estimates the Rao-Scott first- and second-order design correction of the chi-square statistics. All statistics are computed within the groups specified by the last splitting variable. If no splitting variables are added, the results will be computed only by country.
@@ -58,7 +60,7 @@
 #' The function also computes chi-square statistics with Rao-Scott first- and second-order design corrections because of the clustering in complex survey designs. For more details, see Rao & Scott (1984, 1987) and Skinner (2019).
 #'
 #' @return
-#' A MS Excel (\code{.xlsx}) file (which can be opened in any spreadsheet program), as specified with the full path in the \code{output.file}. If the argument is missing, an Excel file with the generic file name "Analysis.xlsx" will be saved in the working directory (\code{getwd()}). The workbook contains four spreadsheets. The first one ("Estimates") contains a table with the results by country and the final part of the table contains averaged results from all countries' statistics. The following columns can be found in the table, depending on the specification of the analysis:
+#' If \code{save.output = FALSE}, a list containing the estimates and analysis information. If \code{save.output = TRUE} (default), an MS Excel (\code{.xlsx}) file (which can be opened in any spreadsheet program), as specified with the full path in the \code{output.file}. If the argument is missing, an Excel file with the generic file name "Analysis.xlsx" will be saved in the working directory (\code{getwd()}). The workbook contains four spreadsheets. The first one ("Estimates") contains a table with the results by country and the final part of the table contains averaged results from all countries' statistics. The following columns can be found in the table, depending on the specification of the analysis:
 #'
 #' \itemize{
 #'   \item \verb{<}Country ID\verb{>} - a column containing the names of the countries in the file for which statistics are computed. The exact column header will depend on the country identifier used in the particular study.
@@ -124,7 +126,7 @@
 #' @seealso \code{\link{lsa.convert.data}}
 #' @export
 
-lsa.crosstabs <- function(data.file, data.object, split.vars, bckg.row.var, bckg.col.var, expected.cnts = TRUE, row.pcts = FALSE, column.pcts = FALSE, total.pcts = FALSE, weight.var, include.missing = FALSE, shortcut = FALSE, output.file, open.output = TRUE) {
+lsa.crosstabs <- function(data.file, data.object, split.vars, bckg.row.var, bckg.col.var, expected.cnts = TRUE, row.pcts = FALSE, column.pcts = FALSE, total.pcts = FALSE, weight.var, include.missing = FALSE, shortcut = FALSE, save.output = TRUE, output.file, open.output = TRUE) {
   tmp.options <- options(scipen = 999, digits = 22)
   on.exit(expr = options(tmp.options), add = TRUE)
   warnings.collector <- list()
@@ -135,6 +137,9 @@ lsa.crosstabs <- function(data.file, data.object, split.vars, bckg.row.var, bckg
     if(file.exists(data.file) == FALSE) {
       stop('The file specified in the "data.file" argument does not exist. All operations stop here. Check your input.\n\n', call. = FALSE)
     }
+    if(!is.logical(save.output) || !save.output %in% c(TRUE, FALSE)) {
+      stop('\nThe "save.output" argument can take only logical values (TRUE or FALSE). All operations stop here. Check your input.', call. = FALSE)
+    }
     ptm.data.import <- proc.time()
     data <- copy(import.data(path = data.file))
     used.data <- deparse(substitute(data.file))
@@ -495,7 +500,11 @@ lsa.crosstabs <- function(data.file, data.object, split.vars, bckg.row.var, bckg
     ptm.add.RS.chi.square <- proc.time()
     Rao.Scott.adj.chi.sq <- rbindlist(l = Rao.Scott.adj.chi.sq)
     message('Rao-Scott adjusted chi-square statistics table assembled in ', format(as.POSIXct("0001-01-01 00:00:00") + {proc.time() - ptm.add.RS.chi.square}[[3]], "%H:%M:%OS3"), "\n")
-    export.results(output.object = estimates, analysis.type = action.args.list[["executed.analysis.function"]], Rao.Scott.adj.chi.sq.obj = Rao.Scott.adj.chi.sq, analysis.info.obj = rbindlist(l = analysis.info), destination.file = output.file, open.exported.file = open.output)
+    if(isTRUE(save.output)) {
+      export.results(output.object = estimates, analysis.type = action.args.list[["executed.analysis.function"]], Rao.Scott.adj.chi.sq.obj = Rao.Scott.adj.chi.sq, analysis.info.obj = rbindlist(l = analysis.info), destination.file = output.file, open.exported.file = open.output)
+    } else if(isFALSE(save.output)) {
+      return(list(Estimates = estimates, `Rao-Scott` = Rao.Scott.adj.chi.sq, `Analysis information` = rbindlist(l = analysis.info)))
+    }
     if(exists("removed.countries.where.any.split.var.is.all.NA") && length(removed.countries.where.any.split.var.is.all.NA) > 0) {
       warning('Some of the countries had one or more splitting variables which contains only missing values. These countries are: "', paste(removed.countries.where.any.split.var.is.all.NA, collapse = '", "'), '".', call. = FALSE)
     }
